interface CompanyRequired {
    origin: string;
    update_time: number;
    plugin_id: string;
    name: string;
    completed: boolean;
}
interface ContactRequired {
    origin: string;
    update_time: number;
    plugin_id: string;
    completed: boolean;
}
interface OriginData {
    origin: string;
    type: Crawler.DataType;
    UID: string;
}
interface PooledDataParams {
    company: Crawler.Company[];
    contact: Crawler.Contact[];
}
interface BindAnchor extends Crawler.Anchor {
    bind_type: 'company' | 'contact';
}
declare class CrawlerUtil {
    readonly uid_separator = "|#|";
    companyModel(require: CompanyRequired): Crawler.Company;
    contactModel(require: ContactRequired): Crawler.Contact;
    /**
     * 获取来源数据id,该id是唯一的，每个数据来源都会有一个唯一的id，
     * @ param {string} id 页面id,唯一的依据，也有可能是一个网址
     * @ param {enum} origin 来源 ['linkedin', 'twitter', 'facebook', 'crunchbase', 'url']，
     * 						linkedin/twitter/facebook/crunchbase的id是urlid,url的id是url
     * @ param {boolean} isCompany 是否是公司数据
     * linkedin|#|contact|#|2q34sdf2rf233f2,facebook|#|contact|2q34sdf2rf233f2
     */
    createUniqueId(id: string | number, origin: string, type?: Crawler.DataType): string;
    isUniqueId(id: string): boolean;
    decodeUniqueId(uniqueId: string): OriginData;
    getUniqueIdLink(uniqueId: string): string;
    /**
     * 获取某个网站的某个cookie值
     * @param {string} name cookie的键（名称）
     * @param domain 网站的域名
     * */
    getCookie(name: string, domain: string): Promise<string | null>;
    setCookie(data: Electron.CookiesSetDetails): Promise<void>;
    /**
     * 获取某个网站的cookie字符串
     * @param {string} domain 网站的域名
     * */
    getDomainCookies(domain: string): Promise<string>;
    extContactToExtCompany(extContact: Crawler.Contact): Crawler.Company;
    extCompanyToExtContact(extCompany: Crawler.Company): Crawler.Contact;
    /**
     * 合并两个联系人
     * @param {Crawler.Contact} origin 原
     * @param {Crawler.Contact} newc 新的
     * */
    mergeContact(origin: Crawler.Contact, newc: Crawler.Contact): void;
    isSameContact(d1: Crawler.Contact, d2: Crawler.Contact): boolean;
    sameAnchor(i: Crawler.Anchor, i2: Crawler.Anchor): boolean;
    isSameCompany(d1: Crawler.Company, d2: Crawler.Company): boolean;
    /**
     * 数据去重合并，判断出为同一个联系人时，会自动合并去重
     * @param {Array[Object]} datas 等待去重的数据数组
     * @param {Crawler.Contact[]} originData 其它数据,datas会先与之对比，如果是同一人，那优先合到originData字段，默认为空数组[]
     * @returns {Array[Object]} 返回非originData,合并后的数据
     * */
    pooledContactData(datas: Crawler.Contact[], originData?: Crawler.Contact[]): Crawler.Contact[];
    /**
     * 数据去重合并，判断出为同一个公司时，会自动合并去重
     * @param {Crawler.Company[]} datas 需要合并的公司数据
     * @param {boolean}   forcedMergers 是否将datas强制合并成一个公司
     * @returns {Crawler.Company[]} 返回自动合并后的数据
     * */
    pooledCompanyData(datas: Crawler.Company[], forcedMergers?: boolean): Crawler.Company[];
    pooledData<T extends keyof PooledDataParams>(datas: PooledDataParams[T], type: T, forcedMergers?: boolean): Crawler.Contact[] | Crawler.Company[];
    /**
     * 判断一个字符串是否为职位名
     * @param {string} str 需要判断的字符串
     * @return {boolean} true:是职位名；false:不是职位名
     * */
    isPosition(str: string): boolean;
    /**
     * 判断一个字符串是否为公司名
     * @param {string} str 需要判断的字符串
     * @return {boolean} true:是公司名；false:不是公司名
     *
     * */
    isCompany(str: string): boolean;
    /**
     * 拆分签名 分解开公司与职位
     * @param {string} label 要分解的字符串
     * @return {[string,string]} [{String}公司名,{String}职位名]
     * */
    labelTreatment(label: string): [string, string];
    /**
     * 获取锚id
     * @param {string} info 锚info
     * @param {string} type 锚类型
     * */
    getAnchorId(info: string, type: string): string | undefined;
    /**
     * url转锚数据
     * @param {string} url
     * @param {'company'|'contact'} 可选，指定锚类型，不传时，先判断是否是company，再判断是否是contact
     * */
    urlToAnchor(url: string, type?: 'contact' | 'company'): BindAnchor | undefined;
}
declare const _default: CrawlerUtil;
export default _default;
export { CrawlerUtil };
